aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/rc/parse.h
diff options
context:
space:
mode:
authorNicholas Noll <nbnoll@eml.cc>2021-12-04 14:10:21 -0800
committerNicholas Noll <nbnoll@eml.cc>2021-12-04 14:10:21 -0800
commit12e09f9f85ac48ff891adf92f3b2c9a5fea27273 (patch)
tree60051793885e9978dadf6672ef85cdda216676a2 /src/cmd/rc/parse.h
parentb80a3d28ce42be4fdec451f74620b10ee75219dc (diff)
Chore(REMOVE): finished deprecation of old io functions.
The old methods were simple wrappers of C standard library functions. We've moved (painfully) over to a new interface that allows for files to live on the stack. All users of the functionality are ported over.
Diffstat (limited to 'src/cmd/rc/parse.h')
-rw-r--r--src/cmd/rc/parse.h31
1 files changed, 15 insertions, 16 deletions
diff --git a/src/cmd/rc/parse.h b/src/cmd/rc/parse.h
index 88859ea..ee56e0c 100644
--- a/src/cmd/rc/parse.h
+++ b/src/cmd/rc/parse.h
@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.8.2. */
+/* A Bison parser, made by GNU Bison 3.7.6. */
/* Bison interface for Yacc-like parsers in C
@@ -39,7 +39,7 @@
# define YY_YY_SRC_CMD_RC_PARSE_H_INCLUDED
/* Debug traces. */
#ifndef YYDEBUG
-# define YYDEBUG 1
+# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
@@ -69,17 +69,18 @@ extern int yydebug;
Tredir = 270, /* Tredir */
Tdup = 271, /* Tdup */
Tpipe = 272, /* Tpipe */
- Tindex = 273, /* Tindex */
- Tbasic = 274, /* Tbasic */
- Targs = 275, /* Targs */
- Tword = 276, /* Tword */
- Twords = 277, /* Twords */
- Tparen = 278, /* Tparen */
- Tblock = 279, /* Tblock */
- Tandand = 280, /* Tandand */
- Toror = 281, /* Toror */
- Tcount = 282, /* Tcount */
- Tjoin = 283 /* Tjoin */
+ Tpipefd = 273, /* Tpipefd */
+ Tindex = 274, /* Tindex */
+ Tbasic = 275, /* Tbasic */
+ Targs = 276, /* Targs */
+ Tword = 277, /* Tword */
+ Twords = 278, /* Twords */
+ Tparen = 279, /* Tparen */
+ Tblock = 280, /* Tblock */
+ Tandand = 281, /* Tandand */
+ Toror = 282, /* Toror */
+ Tcount = 283, /* Tcount */
+ Tjoin = 284 /* Tjoin */
};
typedef enum yytokentype yytoken_kind_t;
#endif
@@ -92,7 +93,7 @@ union YYSTYPE
struct Tree *tree;
-#line 96 "src/cmd/rc/parse.h"
+#line 97 "src/cmd/rc/parse.h"
};
typedef union YYSTYPE YYSTYPE;
@@ -103,8 +104,6 @@ typedef union YYSTYPE YYSTYPE;
extern YYSTYPE yylval;
-
int yyparse (void);
-
#endif /* !YY_YY_SRC_CMD_RC_PARSE_H_INCLUDED */